/** *****************************************************
 * Copyright (C) HRider in motion S.L.
 *
 * This file is part of HRider.
 *
 * HRider can not be copied and/or distributed without the express
 * permission of HRider in motion S.L.
 ****************************************************** */
package net.hrider.api.usecases;

import java.util.logging.Logger;
import net.hrider.api.client.ApiException;
import net.hrider.api.model.Department;
import net.hrider.api.model.Employee;
import net.hrider.api.model.Link;
import net.hrider.api.model.Position;

/**
 * Example to create the followed organization 
 * (DEPT: department, PST: positions, EMP: employees):
 * 
 * COMPANY: ACME
 * 
 *    DEPT1
 *      |____ PSTA
 *      |       |_______ EMP1
 *      |       |_______ EMP2
 *      |
 *      |____ PSTB
 *      |       |_______ EMP3
 *      | 
 *      |____ PSTC
 * 
 * 
 * EMP1 is the supervisor of EMP3 and EMP2
 * EMP2,EMP1 are clients of EMP3
 * 
 * 
 * @author drh (dani@hrider.net)
 */
public class CreateOrganization extends AbstractUseCase {
   
    private static final Logger LOG = Logger.getLogger(CreateOrganization.class.getName());

    @Override
    public void doRun() throws ApiException {               
        // create department DEPT1 following the link's company "departments"
        Department dpt1 = service.create(getDummyCompany().getLinks().getDepartments(), 
                buildDepartment("DEPT1", "DEPARTMENT 1"));
        
        // create positions A, B, C in department DEPT1 following its link "positions"
        Link positionsLink = dpt1.getLinks().getPositions();
        Position pa = service.create(positionsLink, buildPosition("PSTA", "POSITION A", 2));
        Position pb = service.create(positionsLink, buildPosition("PSTB", "POSITION B", 1));
        Position pc = service.create(positionsLink, buildPosition("PSTC", "POSITION C", 1));
        
        // create employees 
        Link employeesLink = getDummyCompany().getLinks().getEmployees();
        Employee emp1 = service.create(employeesLink, buildEmployee("EMP1", "Employee 1", "emp1@acme.com"));
        Employee emp2 = service.create(employeesLink, buildEmployee("EMP2", "Employee 2", "emp2@acme.com"));
        Employee emp3 = service.create(employeesLink, buildEmployee("EMP3", "Employee 3", "emp2@acme.com"));        
        
        // enroll EMP1, EMP2 in PSTA and EMP3 in PSTB
        service.put(emp1.getLinks().getPosition(), pa.getLinks().getSelf().getHref());
        service.put(emp2.getLinks().getPosition(), pa.getLinks().getSelf().getHref());
        service.put(emp3.getLinks().getPosition(), pb.getLinks().getSelf().getHref());
        
        // set supervisor EMP1 <- EMP2 and EMP3
        service.put(emp2.getLinks().getSupervisor(), emp1.getLinks().getSelf().getHref());
        service.put(emp3.getLinks().getSupervisor(), emp1.getLinks().getSelf().getHref());
        
        // set EMP2 and EMP1 clients of EMP3
        service.put(emp3.getLinks().getClients(), 
                emp2.getLinks().getSelf().getHref() + "\n" +
                emp1.getLinks().getSelf().getHref());
    }
        
    public static void main(String[] args) {
        (new CreateOrganization()).run();
    }
}
